@@ -27,10 +27,26 @@
 #' specification of the column names. The validation function can be used
 #' directly on a data table or with an *agent* object (technically, a
 #' `ptblank_agent` object) whereas the expectation and test functions can only
-#' be used with a data table. The types of data tables that can be used include
-#' data frames, tibbles, database tables (`tbl_dbi`), and Spark DataFrames
-#' (`tbl_spark`). Each validation step or expectation will operate over a single
-#' test unit, which is whether the column is a factor-type column or not.
+#' be used with a data table. Each validation step or expectation will operate
+#' over a single test unit, which is whether the column is a factor-type column
+#' or not.
+#' 
+#' @section Supported Input Tables:
+#' The types of data tables that are officially supported are:
+#' 
+#'  - data frames (`data.frame`) and tibbles (`tbl_df`)
+#'  - Spark DataFrames (`tbl_spark`)
+#'  - the following database tables (`tbl_dbi`):
+#'    - *PostgreSQL* tables (using the `RPostgres::Postgres()` as driver)
+#'    - *MySQL* tables (with `RMySQL::MySQL()`)
+#'    - *Microsoft SQL Server* tables (via **odbc**)
+#'    - *BigQuery* tables (using `bigrquery::bigquery()`)
+#'    - *DuckDB* tables (through `duckdb::duckdb()`)
+#'    - *SQLite* (with `RSQLite::SQLite()`)
+#'    
+#' Other database tables may work to varying degrees but they haven't been
+#' formally tested (so be mindful of this when using unsupported backends with
+#' **pointblank**).
 #' 
 #' @section Column Names:
 #' If providing multiple column names, the result will be an expansion of
@@ -70,17 +86,21 @@
 #' validation step is expressed in R code and in the corresponding YAML
 #' representation.
 #' 
-#' ```
-#' # R statement
+#' R statement:
+#' 
+#' ```r
 #' agent %>% 
 #'   col_is_factor(
-#'     vars(a),
+#'     columns = vars(a),
 #'     actions = action_levels(warn_at = 0.1, stop_at = 0.2),
 #'     label = "The `col_is_factor()` step.",
 #'     active = FALSE
 #'   )
+#' ```
 #' 
-#' # YAML representation
+#' YAML representation:
+#' 
+#' ```yaml
 #' steps:
 #' - col_is_factor:
 #'     columns: vars(a)
@@ -107,64 +127,71 @@
 #'   called primarily for its potential side-effects (e.g., signaling failure).
 #'   The test function returns a logical value.
 #'
-#' @examples
-#' # Let's modify the `f` column in the
-#' # `small_table` dataset so that the
-#' # values are factors instead of having
-#' # the `character` class; the following
-#' # examples will validate that the `f`
-#' # column was successfully mutated and
-#' # now consists of factors
+#' @section Examples:
+#' 
+#' Let's modify the `f` column in the `small_table` dataset so that the values
+#' are factors instead of having the `character` class. The following examples
+#' will validate that the `f` column was successfully mutated and now consists
+#' of factors.
+#' 
+#' ```{r}
 #' tbl <- 
 #'   small_table %>%
 #'   dplyr::mutate(f = factor(f))
-#' 
-#' # A: Using an `agent` with validation
-#' #    functions and then `interrogate()`
-#' 
-#' # Validate that the column `f` in the
-#' # `tbl` object is of the `factor` class
-#' agent <-
-#'   create_agent(tbl) %>%
-#'   col_is_factor(vars(f)) %>%
-#'   interrogate()
 #'   
-#' # Determine if this validation
-#' # had no failing test units (1)
-#' all_passed(agent)
+#' tbl
+#' ```
 #' 
-#' # Calling `agent` in the console
-#' # prints the agent's report; but we
-#' # can get a `gt_tbl` object directly
-#' # with `get_agent_report(agent)`
+#' ## A: Using an `agent` with validation functions and then `interrogate()`
 #' 
-#' # B: Using the validation function
-#' #    directly on the data (no `agent`)
+#' Validate that the column `f` in the `tbl` object is of the `factor` class.
 #' 
-#' # This way of using validation functions
-#' # acts as a data filter: data is passed
-#' # through but should `stop()` if there
-#' # is a single test unit failing; the
-#' # behavior of side effects can be
-#' # customized with the `actions` option
+#' ```r
+#' agent <-
+#'   create_agent(tbl = tbl) %>%
+#'   col_is_factor(columns = vars(f)) %>%
+#'   interrogate()
+#' ```
+#' 
+#' Printing the `agent` in the console shows the validation report in the
+#' Viewer. Here is an excerpt of validation report, showing the single entry
+#' that corresponds to the validation step demonstrated here.
+#' 
+#' \if{html}{
+#' \out{
+#' `r pb_get_image_tag(file = "man_col_is_factor_1.png")`
+#' }
+#' }
+#' 
+#' ## B: Using the validation function directly on the data (no `agent`)
+#' 
+#' This way of using validation functions acts as a data filter. Data is passed
+#' through but should `stop()` if there is a single test unit failing. The
+#' behavior of side effects can be customized with the `actions` option.
+#' 
+#' ```{r}
 #' tbl %>%
-#'   col_is_factor(vars(f)) %>%
+#'   col_is_factor(columns = vars(f)) %>%
 #'   dplyr::slice(1:5)
+#' ```
 #' 
-#' # C: Using the expectation function
+#' ## C: Using the expectation function
 #' 
-#' # With the `expect_*()` form, we would
-#' # typically perform one validation at a
-#' # time; this is primarily used in
-#' # testthat tests
+#' With the `expect_*()` form, we would typically perform one validation at a
+#' time. This is primarily used in **testthat** tests.
+#' 
+#' ```r
 #' expect_col_is_factor(tbl, vars(f))
+#' ```
 #' 
-#' # D: Using the test function
+#' ## D: Using the test function
 #' 
-#' # With the `test_*()` form, we should
-#' # get a single logical value returned
-#' # to us
-#' tbl %>% test_col_is_factor(vars(f))
+#' With the `test_*()` form, we should get a single logical value returned to
+#' us.
+#' 
+#' ```{r}
+#' tbl %>% test_col_is_factor(columns = vars(f))
+#' ```
 #' 
 #' @family validation functions
 #' @section Function ID:
@@ -176,13 +203,15 @@ NULL
 #' @rdname col_is_factor
 #' @import rlang
 #' @export
-col_is_factor <- function(x,
-                          columns,
-                          actions = NULL,
-                          step_id = NULL,
-                          label = NULL,
-                          brief = NULL,
-                          active = TRUE) {
+col_is_factor <- function(
+    x,
+    columns,
+    actions = NULL,
+    step_id = NULL,
+    label = NULL,
+    brief = NULL,
+    active = TRUE
+) {
   
   preconditions <- NULL
   values <- NULL
@@ -259,9 +288,11 @@ col_is_factor <- function(x,
 #' @rdname col_is_factor
 #' @import rlang
 #' @export
-expect_col_is_factor <- function(object,
-                                 columns,
-                                 threshold = 1) {
+expect_col_is_factor <- function(
+    object,
+    columns,
+    threshold = 1
+) {
   
   fn_name <- "expect_col_is_factor"
   
@@ -332,9 +363,11 @@ expect_col_is_factor <- function(object,
 #' @rdname col_is_factor
 #' @import rlang
 #' @export
-test_col_is_factor <- function(object,
-                               columns,
-                               threshold = 1) {
+test_col_is_factor <- function(
+    object,
+    columns,
+    threshold = 1
+) {
   
   vs <- 
     create_agent(tbl = object, label = "::QUIET::") %>%
