@@ -25,11 +25,27 @@
 #' whether column values in a table agree with a user-defined predicate
 #' expression. The validation function can be used directly on a data table or
 #' with an *agent* object (technically, a `ptblank_agent` object) whereas the
-#' expectation and test functions can only be used with a data table. The types
-#' of data tables that can be used include data frames, tibbles, database tables
-#' (`tbl_dbi`), and Spark DataFrames (`tbl_spark`). Each validation step or
-#' expectation will operate over the number of test units that is equal to the
-#' number of rows in the table (after any `preconditions` have been applied).
+#' expectation and test functions can only be used with a data table. Each
+#' validation step or expectation will operate over the number of test units
+#' that is equal to the number of rows in the table (after any `preconditions`
+#' have been applied).
+#' 
+#' @section Supported Input Tables:
+#' The types of data tables that are officially supported are:
+#' 
+#'  - data frames (`data.frame`) and tibbles (`tbl_df`)
+#'  - Spark DataFrames (`tbl_spark`)
+#'  - the following database tables (`tbl_dbi`):
+#'    - *PostgreSQL* tables (using the `RPostgres::Postgres()` as driver)
+#'    - *MySQL* tables (with `RMySQL::MySQL()`)
+#'    - *Microsoft SQL Server* tables (via **odbc**)
+#'    - *BigQuery* tables (using `bigrquery::bigquery()`)
+#'    - *DuckDB* tables (through `duckdb::duckdb()`)
+#'    - *SQLite* (with `RSQLite::SQLite()`)
+#'    
+#' Other database tables may work to varying degrees but they haven't been
+#' formally tested (so be mindful of this when using unsupported backends with
+#' **pointblank**).
 #' 
 #' @section Preconditions:
 #' Providing expressions as `preconditions` means **pointblank** will preprocess
@@ -111,8 +127,9 @@
 #' validation step is expressed in R code and in the corresponding YAML
 #' representation.
 #' 
-#' ```
-#' # R statement
+#' R statement:
+#' 
+#' ```r
 #' agent %>% 
 #'   col_vals_expr(
 #'     expr = ~ a %% 1 == 0,
@@ -122,8 +139,11 @@
 #'     label = "The `col_vals_expr()` step.",
 #'     active = FALSE
 #'   )
+#' ```
 #' 
-#' # YAML representation
+#' YAML representation:
+#' 
+#' ```yaml
 #' steps:
 #' - col_vals_expr:
 #'     expr: ~a%%1 == 0
@@ -155,91 +175,98 @@
 #'   called primarily for its potential side-effects (e.g., signaling failure).
 #'   The test function returns a logical value.
 #' 
-#' @examples
-#' # For all of the examples here, we'll
-#' # use a simple table with three numeric
-#' # columns (`a`, `b`, and `c`) and three
-#' # character columns (`d`, `e`, and `f`)
+#' @section Examples:
+#' 
+#' For all of the examples here, we'll use a simple table with three numeric
+#' columns (`a`, `b`, and `c`) and three character columns (`d`, `e`, and `f`).
+#' 
+#' ```{r}
 #' tbl <-
 #'   dplyr::tibble(
 #'     a = c(1, 2, 1, 7, 8, 6),
 #'     b = c(0, 0, 0, 1, 1, 1),
 #'     c = c(0.5, 0.3, 0.8, 1.4, 1.9, 1.2),
 #'   )
-#'   
+#' 
 #' tbl
+#' ```
 #' 
-#' # A: Using an `agent` with validation
-#' #    functions and then `interrogate()` 
+#' ## A: Using an `agent` with validation functions and then `interrogate()`
 #' 
-#' # Validate that values in column `a`
-#' # are integer-like by using the R modulo
-#' # operator and expecting `0`
+#' Validate that values in column `a` are integer-like by using the R modulo
+#' operator and expecting `0`. We'll determine if this validation has any
+#' failing test units (there are 6 test units, one for each row).
+#' 
+#' ```r
 #' agent <-
-#'   create_agent(tbl) %>%
-#'   col_vals_expr(expr(a %% 1 == 0)) %>%
+#'   create_agent(tbl = tbl) %>%
+#'   col_vals_expr(expr = expr(a %% 1 == 0)) %>%
 #'   interrogate()
+#' ```
 #' 
-#' # Determine if this validation
-#' # had no failing test units (there
-#' # are 6 test units, one for each row)
-#' all_passed(agent)
+#' Printing the `agent` in the console shows the validation report in the
+#' Viewer. Here is an excerpt of validation report, showing the single entry
+#' that corresponds to the validation step demonstrated here.
 #' 
-#' # Calling `agent` in the console
-#' # prints the agent's report; but we
-#' # can get a `gt_tbl` object directly
-#' # with `get_agent_report(agent)`
+#' \if{html}{
+#' \out{
+#' `r pb_get_image_tag(file = "man_col_vals_expr_1.png")`
+#' }
+#' }
 #' 
-#' # B: Using the validation function
-#' #    directly on the data (no `agent`)
+#' ## B: Using the validation function directly on the data (no `agent`)
 #' 
-#' # This way of using validation functions
-#' # acts as a data filter: data is passed
-#' # through but should `stop()` if there
-#' # is a single test unit failing; the
-#' # behavior of side effects can be
-#' # customized with the `actions` option
+#' This way of using validation functions acts as a data filter. Data is passed
+#' through but should `stop()` if there is a single test unit failing. The
+#' behavior of side effects can be customized with the `actions` option.
+#' 
+#' ```{r}
 #' tbl %>% 
-#'   col_vals_expr(expr(a %% 1 == 0)) %>%
+#'   col_vals_expr(expr = expr(a %% 1 == 0)) %>%
 #'   dplyr::pull(a)
+#' ```
 #'   
-#' # C: Using the expectation function
+#' ## C: Using the expectation function
 #' 
-#' # With the `expect_*()` form, we would
-#' # typically perform one validation at a
-#' # time; this is primarily used in
-#' # testthat tests
-#' expect_col_vals_expr(tbl, ~ a %% 1 == 0)
+#' With the `expect_*()` form, we would typically perform one validation at a
+#' time. This is primarily used in **testthat** tests.
 #' 
-#' # D: Using the test function
+#' ```r
+#' expect_col_vals_expr(tbl, expr = ~ a %% 1 == 0)
+#' ```
 #' 
-#' # With the `test_*()` form, we should
-#' # get a single logical value returned
-#' # to us
-#' test_col_vals_expr(tbl, ~ a %% 1 == 0)
+#' ## D: Using the test function
 #' 
-#' # Variations
+#' With the `test_*()` form, we should get a single logical value returned to
+#' us.
 #' 
-#' # We can do more complex things by
-#' # taking advantage of the `case_when()`
-#' # and `between()` functions (available
-#' # for use in the pointblank package) 
+#' ```{r}
+#' test_col_vals_expr(tbl, expr = ~ a %% 1 == 0)
+#' ```
+#' 
+#' ## Variations
+#' 
+#' We can do more complex things by taking advantage of the `case_when()` and
+#' `between()` functions (available for use in the **pointblank** package).
+#' 
+#' ```{r}
 #' tbl %>%
-#'   test_col_vals_expr(~ case_when(
+#'   test_col_vals_expr(expr = ~ case_when(
 #'     b == 0 ~ a %>% between(0, 5) & c < 1,
 #'     b == 1 ~ a > 5 & c >= 1
 #'   ))
+#' ```
 #' 
-#' # If you only want to test a subset of
-#' # rows, then the `case_when()` statement
-#' # doesn't need to be exhaustive; any
-#' # rows that don't fall into the cases
-#' # will be pruned (giving us less test
-#' # units overall) 
+#' If you only want to test a subset of rows, then the `case_when()` statement
+#' doesn't need to be exhaustive. Any rows that don't fall into the cases will
+#' be pruned (giving us less test units overall).
+#' 
+#' ```{r}
 #' tbl %>%
-#'   test_col_vals_expr(~ case_when(
+#'   test_col_vals_expr(expr = ~ case_when(
 #'     b == 1 ~ a > 5 & c >= 1
 #'   ))
+#' ```
 #' 
 #' @family validation functions
 #' @section Function ID:
@@ -255,15 +282,17 @@ NULL
 #' @rdname col_vals_expr
 #' @import rlang
 #' @export
-col_vals_expr <- function(x,
-                          expr,
-                          preconditions = NULL,
-                          segments = NULL,
-                          actions = NULL,
-                          step_id = NULL,
-                          label = NULL,
-                          brief = NULL,
-                          active = TRUE) {
+col_vals_expr <- function(
+    x,
+    expr,
+    preconditions = NULL,
+    segments = NULL,
+    actions = NULL,
+    step_id = NULL,
+    label = NULL,
+    brief = NULL,
+    active = TRUE
+) {
   
   if (!inherits(expr, "call")) {
     
@@ -362,10 +391,12 @@ col_vals_expr <- function(x,
 #' @rdname col_vals_expr
 #' @import rlang
 #' @export
-expect_col_vals_expr <- function(object,
-                                 expr,
-                                 preconditions = NULL,
-                                 threshold = 1) {
+expect_col_vals_expr <- function(
+    object,
+    expr,
+    preconditions = NULL,
+    threshold = 1
+) {
   
   fn_name <- "expect_col_vals_expr"
   
@@ -415,10 +446,12 @@ expect_col_vals_expr <- function(object,
 #' @rdname col_vals_expr
 #' @import rlang
 #' @export
-test_col_vals_expr <- function(object,
-                               expr,
-                               preconditions = NULL,
-                               threshold = 1) {
+test_col_vals_expr <- function(
+    object,
+    expr,
+    preconditions = NULL,
+    threshold = 1
+) {
   
   vs <- 
     create_agent(tbl = object, label = "::QUIET::") %>%
